==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/audittrail_br/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Auditoria',
    'version': '7.0.21.12.14',
    'category': 'Sem definicao',
    'description': """
    Modulo de Auditoria nas tabela do sistema SigERP
    """,
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['base_setup'],
    'data': [
        'wizard/audittrail_view_log_view.xml',
        'views/audittrail_rule_view.xml',
        'views/audittrail_log_view.xml',
        'security/ir.model.access.csv',
        'security/audittrail_security.xml',
        'views/action.xml',
        'views/menu.xml'
    ],
    'installable': True,
    'active': False,
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/audittrail_br/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Auditoria',
    'version': '7.0.2310.2',
    'category': 'Sem definicao',
    'description': """
    Modulo de Auditoria nas tabela do sistema SigERP
    """,
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['base_setup'],
    'data': [
        'wizard/audittrail_view_log_view.xml',
        'views/audittrail_rule_view.xml',
        'views/audittrail_log_view.xml',
        'security/ir.model.access.csv',
        'security/audittrail_security.xml',
        'views/action.xml',
        'views/menu.xml'
    ],
    'installable': True,
    'active': False,
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
